@@ -3392,7 +3392,7 @@ push_source_open_cb (GObject *source, GAsyncResult *res, gpointer user_data)
         {
           /* Fall back to default implementation to improve the error message */
           g_vfs_job_failed (handle->job, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-                            _("Not supported"));
+                            _("Operation not supported"));
         }
       else
         g_vfs_job_failed_from_error (handle->job, error);
@@ -3424,7 +3424,7 @@ push_source_lstat_cb (GObject *source, GAsyncResult *res, gpointer user_data)
     {
       /* Fall back to default implementation to copy symlink */
       g_vfs_job_failed (handle->job, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-                        _("Not supported"));
+                        _("Operation not supported"));
       push_handle_free (handle);
       g_object_unref (info);
       return;
